This is sportstat, a Python package that I hope will give more people access to soccer data. Gone are the days of downloading spreadsheets one-by-one, copy-pasting, or entering data into spreadsheets by hand. I try to make sportstat as easy-to-use as possible so that anybody with a bit of Python experience can use it.

To install sportstat, run ```pip install sportstat``` from the command line.

Data can be scraped from the following sources:
* [FBRef](https://fbref.com/en/)
    * Match and seasonal data for players and teams
* [Understat](https://understat.com/)
    * Match and seasonal data for players and teams
* [FiveThirtyEight](https://projects.fivethirtyeight.com/soccer-predictions/)
    * Several FiveThirtyEight metrics on a match level (SPI, win probabilities, xG, NSxG, and more)
* [ClubELO](http://clubelo.com/)
    * ELO scores for teams on a specific date
* [Capology](https://www.capology.com/)
    * Player salary data
* [Transfermarkt](https://www.transfermarkt.us/)
    * Market value, transfer history, market value history, and more

For documentation, head over to the [GitHub's wiki page](https://github.com/oseymour/sportstat/wiki)

For usage examples, look at Examples.ipynb in the code directory or some of my example analyses in the analytics_examples folder.

I'd love to hear your feedback, bugs you find, or new features you want! You can reach me via email at osmour043@gmail.com or my Twitter handle is [@owen_seymour](https://twitter.com/owen_seymour).
